==> oneChannelGUI_1.26.0.tar.gz: oneChannelGUI/R/helpmenu.R <==
#set of functions, directly/indirectly involved, in oneChannelGUI helpMenu
#oneChannelGUI siggenesHelp
#oneChannelGUI
#RETIRED oneChannelGUI changes gives info on the latest updates on oneChannelGUI
#A pdf was added as vignette to descrive the oneChannelGUI update 
################################################################################

affyPLMHelp <- function()
{
	Try(affyPLMHelpIndex <- file.path(system.file("doc",package="affyPLM"),"index.html"))
	Try(browseURL(affyPLMHelpIndex))
	##Try(tkmessageBox(title="limma Help",message=paste("Opening limma help...\nIf nothing happens, please open :\n",limmaHelpIndex,"\nyourself.",sep="")))
	Try(cat(paste("Opening affyPLM help...\nIf nothing happens, please open :\n",affyPLMHelpIndex,"\nyourself.",sep="")))
}
################################################################################

pdmclassHelp <- function()
{
	Try(pdmclassHelpIndex <- file.path(system.file("doc",package="pdmclass"),"index.html"))
	Try(browseURL(pdmclassHelpIndex))
	##Try(tkmessageBox(title="limma Help",message=paste("Opening limma help...\nIf nothing happens, please open :\n",limmaHelpIndex,"\nyourself.",sep="")))
	Try(cat(paste("Opening pdmclass help...\nIf nothing happens, please open :\n",pdmclassHelpIndex,"\nyourself.",sep="")))
}
################################################################################

pamrHelp <- function()
{
	Try(pamrHelpIndex <- file.path(system.file("doc",package="pamr"),"index.html"))
	Try(browseURL(pamrHelpIndex))
	##Try(tkmessageBox(title="limma Help",message=paste("Opening limma help...\nIf nothing happens, please open :\n",limmaHelpIndex,"\nyourself.",sep="")))
	Try(cat(paste("Opening pamr help...\nIf nothing happens, please open :\n",pamrHelpIndex,"\nyourself.",sep="")))
}
################################################################################

ssizeHelp <- function()
{
	Try(ssizeHelpIndex <- file.path(system.file("doc",package="ssize"),"index.html"))
	Try(browseURL(ssizeHelpIndex))
	##Try(tkmessageBox(title="limma Help",message=paste("Opening limma help...\nIf nothing happens, please open :\n",limmaHelpIndex,"\nyourself.",sep="")))
	Try(cat(paste("Opening ssize help...\nIf nothing happens, please open :\n",ssizeHelpIndex,"\nyourself.",sep="")))
}
################################################################################

sizepowerHelp <- function()
{
	Try(sizepowerHelpIndex <- file.path(system.file("doc",package="sizepower"),"index.html"))
	Try(browseURL(sizepowerHelpIndex))
	##Try(tkmessageBox(title="limma Help",message=paste("Opening limma help...\nIf nothing happens, please open :\n",limmaHelpIndex,"\nyourself.",sep="")))
	Try(cat(paste("Opening sizepower help...\nIf nothing happens, please open :\n",sizepowerHelpIndex,"\nyourself.",sep="")))
}
################################################################################

genefilterHelp <- function()
{
	Try(genefilterHelpIndex <- file.path(system.file("doc",package="genefilter"),"index.html"))
	Try(browseURL(genefilterHelpIndex))
	##Try(tkmessageBox(title="limma Help",message=paste("Opening limma help...\nIf nothing happens, please open :\n",limmaHelpIndex,"\nyourself.",sep="")))
	Try(cat(paste("Opening genefilter help...\nIf nothing happens, please open :\n",genefilterHelpIndex,"\nyourself.",sep="")))
}
################################################################################

siggenesHelp <- function()
{
	Try(siggenesHelpIndex <- file.path(system.file("doc",package="siggenes"),"index.html"))
	Try(browseURL(siggenesHelpIndex))
	##Try(tkmessageBox(title="limma Help",message=paste("Opening limma help...\nIf nothing happens, please open :\n",limmaHelpIndex,"\nyourself.",sep="")))
	Try(cat(paste("Opening siggenes help...\nIf nothing happens, please open :\n",siggenesHelpIndex,"\nyourself.",sep="")))
}
################################################################################

GOstatsHelp <- function()
{
	Try(GOstatsHelpIndex <- file.path(system.file("doc",package="GOstats"),"index.html"))
	Try(browseURL(GOstatsHelpIndex))
	##Try(tkmessageBox(title="limma Help",message=paste("Opening limma help...\nIf nothing happens, please open :\n",limmaHelpIndex,"\nyourself.",sep="")))
	Try(cat(paste("Opening GOstats help...\nIf nothing happens, please open :\n",GOstatsHelpIndex,"\nyourself.",sep="")))
}
################################################################################

maSigProHelp <- function()
{
	Try(maSigProHelpIndex <- file.path(system.file("doc",package="maSigPro"),"index.html"))
	Try(browseURL(maSigProHelpIndex))
	##Try(tkmessageBox(title="limma Help",message=paste("Opening limma help...\nIf nothing happens, please open :\n",limmaHelpIndex,"\nyourself.",sep="")))
	Try(cat(paste("Opening maSigPro help...\nIf nothing happens, please open :\n",maSigProHelpIndex,"\nyourself.",sep="")))
}
################################################################################

RankProdHelp <- function()
{
	Try(RankProdHelpIndex <- file.path(system.file("doc",package="RankProd"),"index.html"))
	Try(browseURL(RankProdHelpIndex))
	##Try(tkmessageBox(title="limma Help",message=paste("Opening limma help...\nIf nothing happens, please open :\n",limmaHelpIndex,"\nyourself.",sep="")))
	Try(cat(paste("Opening RankProd help...\nIf nothing happens, please open :\n",RankProdHelpIndex,"\nyourself.",sep="")))
}
################################################################################

oneChannelGUIHelp <- function()
{
	Try(oneChannelGUIHelpIndex <- file.path(system.file("doc",package="oneChannelGUI"),"index.html"))
	Try(browseURL(oneChannelGUIHelpIndex))
	##Try(tkmessageBox(title="limma Help",message=paste("Opening limma help...\nIf nothing happens, please open :\n",limmaHelpIndex,"\nyourself.",sep="")))
	Try(cat(paste("Opening oneChannelGUI help...\nIf nothing happens, please open :\n",oneChannelGUIHelpIndex,"\nyourself.",sep="")))
}
################################################################################

"AboutaffylmGUI" <- function()
{
    Try(tkmessageBox(title="About affylmGUI",message=paste("Basic affylmGUI ", getPackageVersion("affylmGUI") , ", Wettenhall et al. Bioinformatics 2004, 22:897-899, ",
                              ", using limma Version ",getPackageVersion("limma"),".  The limma package was developed by Gordon Smyth and the Graphical User Interface (GUI) was developed by James Wettenhall.",sep=""),type="ok",icon="info"))
}

################################################################################

"AboutextendedaffylmGUI" <- function()
{
    Try(tkmessageBox(title=paste("About oneChannelGUI ", getPackageVersion("oneChannelGUI"), sep=""),message=paste("Basic affylmGUI ", getPackageVersion("affylmGUI") , ", originally designed by James Wettenhall and Ken Simpson, was extended by Raffaele A. Calogero: Sanges et al. Bioinformatics 2007, 23:3406-8. ",
                              "\nUsing limma Version ",getPackageVersion("limma"),".  The limma package was developed by Gordon Smyth and the Graphical User Interface (GUI) was developed by James Wettenhall.",sep=""),type="ok",icon="info"))
}

################################################################################

"changes" <- function(){
         Try(cat("\nLatest major changes in oneChannelGUI:\n"))
         Try(cat("\n1.8.8 Bioconductor BeadStudion V3:"))
         Try(cat("\n\treport generated by BeadStudio V3 can be loaded in oneChannelGUI\n."))
         Try(cat("\n\tBeadStudio V3 report MUST be a GROUP PROBE PROFILE containing the following fields:\n"))
         Try(cat("\n\t\tColumns:\n"))
         Try(cat("\n\t\tProbeId\n"))
         Try(cat("\n\t\tXXXXXXX_A\n"))
         Try(cat("\n\t\t.........\n"))
         Try(cat("\n\t\tXXXXXXX_F\n"))
         Try(cat("\n\t\t\tSubcolumns:\n"))
         Try(cat("\n\t\t\tAVG_Signal\n."))
         Try(cat("\n1.8.9 Bioconductor:"))
         Try(cat("\n\tfast parameter in GCRMA is set to FALSE\n."))
         Try(cat("\n1.10.7 Bioconductor:"))
         Try(cat("\n\tRevised annotation for variant exons has been added. After statistical detection of putative splicing\n."))
         Try(cat("\n\tit is now possible to select only exon-level probesets associated to non-costitutive exons,\n."))
         Try(cat("\n\ti.e. those exons associated only to a to a subset of isoforms\n."))
         Try(cat("\n1.10.8 Bioconductor:"))
         Try(cat("\n\tAdded Cosie method to correct SI index: Gaidatzis et al. Nucleic Acids Research, 2009, pg. 1\n."))
         Try(cat("\n\tSince intcor function from metaArray package has a bug it was sobstituted by intCor from MergeMaid package\n."))
         #gathering affy libs and apt tools folders
         Try(netaffxUpdates  <- paste(.path.package("oneChannelGUI", quiet = FALSE), "/etc/netaffxUpdates.txt", sep=""))
         Try(cat("\nNetaffx library files were updated from user on:\n"))
         Try(cat(readLines(netaffxUpdates), sep="\n"))
}

==> oneChannelGUI_1.38.0.tar.gz: oneChannelGUI/R/helpmenu.R <==
#set of functions, directly/indirectly involved, in oneChannelGUI helpMenu
#oneChannelGUI siggenesHelp
#oneChannelGUI
#RETIRED oneChannelGUI changes gives info on the latest updates on oneChannelGUI
#A pdf was added as vignette to descrive the oneChannelGUI update 
################################################################################

affyPLMHelp <- function()
{
	Try(affyPLMHelpIndex <- file.path(system.file("doc",package="affyPLM"),"index.html"))
	Try(browseURL(affyPLMHelpIndex))
	##Try(tkmessageBox(title="limma Help",message=paste("Opening limma help...\nIf nothing happens, please open :\n",limmaHelpIndex,"\nyourself.",sep="")))
	Try(cat(paste("Opening affyPLM help...\nIf nothing happens, please open :\n",affyPLMHelpIndex,"\nyourself.",sep="")))
}
################################################################################

pdmclassHelp <- function()
{
	Try(pdmclassHelpIndex <- file.path(system.file("doc",package="pdmclass"),"index.html"))
	Try(browseURL(pdmclassHelpIndex))
	##Try(tkmessageBox(title="limma Help",message=paste("Opening limma help...\nIf nothing happens, please open :\n",limmaHelpIndex,"\nyourself.",sep="")))
	Try(cat(paste("Opening pdmclass help...\nIf nothing happens, please open :\n",pdmclassHelpIndex,"\nyourself.",sep="")))
}
################################################################################

pamrHelp <- function()
{
	Try(pamrHelpIndex <- file.path(system.file("doc",package="pamr"),"index.html"))
	Try(browseURL(pamrHelpIndex))
	##Try(tkmessageBox(title="limma Help",message=paste("Opening limma help...\nIf nothing happens, please open :\n",limmaHelpIndex,"\nyourself.",sep="")))
	Try(cat(paste("Opening pamr help...\nIf nothing happens, please open :\n",pamrHelpIndex,"\nyourself.",sep="")))
}
################################################################################

ssizeHelp <- function()
{
	Try(ssizeHelpIndex <- file.path(system.file("doc",package="ssize"),"index.html"))
	Try(browseURL(ssizeHelpIndex))
	##Try(tkmessageBox(title="limma Help",message=paste("Opening limma help...\nIf nothing happens, please open :\n",limmaHelpIndex,"\nyourself.",sep="")))
	Try(cat(paste("Opening ssize help...\nIf nothing happens, please open :\n",ssizeHelpIndex,"\nyourself.",sep="")))
}
################################################################################

sizepowerHelp <- function()
{
	Try(sizepowerHelpIndex <- file.path(system.file("doc",package="sizepower"),"index.html"))
	Try(browseURL(sizepowerHelpIndex))
	##Try(tkmessageBox(title="limma Help",message=paste("Opening limma help...\nIf nothing happens, please open :\n",limmaHelpIndex,"\nyourself.",sep="")))
	Try(cat(paste("Opening sizepower help...\nIf nothing happens, please open :\n",sizepowerHelpIndex,"\nyourself.",sep="")))
}
################################################################################

genefilterHelp <- function()
{
	Try(genefilterHelpIndex <- file.path(system.file("doc",package="genefilter"),"index.html"))
	Try(browseURL(genefilterHelpIndex))
	##Try(tkmessageBox(title="limma Help",message=paste("Opening limma help...\nIf nothing happens, please open :\n",limmaHelpIndex,"\nyourself.",sep="")))
	Try(cat(paste("Opening genefilter help...\nIf nothing happens, please open :\n",genefilterHelpIndex,"\nyourself.",sep="")))
}
################################################################################

siggenesHelp <- function()
{
	Try(siggenesHelpIndex <- file.path(system.file("doc",package="siggenes"),"index.html"))
	Try(browseURL(siggenesHelpIndex))
	##Try(tkmessageBox(title="limma Help",message=paste("Opening limma help...\nIf nothing happens, please open :\n",limmaHelpIndex,"\nyourself.",sep="")))
	Try(cat(paste("Opening siggenes help...\nIf nothing happens, please open :\n",siggenesHelpIndex,"\nyourself.",sep="")))
}
################################################################################

GOstatsHelp <- function()
{
	Try(GOstatsHelpIndex <- file.path(system.file("doc",package="GOstats"),"index.html"))
	Try(browseURL(GOstatsHelpIndex))
	##Try(tkmessageBox(title="limma Help",message=paste("Opening limma help...\nIf nothing happens, please open :\n",limmaHelpIndex,"\nyourself.",sep="")))
	Try(cat(paste("Opening GOstats help...\nIf nothing happens, please open :\n",GOstatsHelpIndex,"\nyourself.",sep="")))
}
################################################################################

maSigProHelp <- function()
{
	Try(maSigProHelpIndex <- file.path(system.file("doc",package="maSigPro"),"index.html"))
	Try(browseURL(maSigProHelpIndex))
	##Try(tkmessageBox(title="limma Help",message=paste("Opening limma help...\nIf nothing happens, please open :\n",limmaHelpIndex,"\nyourself.",sep="")))
	Try(cat(paste("Opening maSigPro help...\nIf nothing happens, please open :\n",maSigProHelpIndex,"\nyourself.",sep="")))
}
################################################################################

RankProdHelp <- function()
{
	Try(RankProdHelpIndex <- file.path(system.file("doc",package="RankProd"),"index.html"))
	Try(browseURL(RankProdHelpIndex))
	##Try(tkmessageBox(title="limma Help",message=paste("Opening limma help...\nIf nothing happens, please open :\n",limmaHelpIndex,"\nyourself.",sep="")))
	Try(cat(paste("Opening RankProd help...\nIf nothing happens, please open :\n",RankProdHelpIndex,"\nyourself.",sep="")))
}
################################################################################

oneChannelGUIHelp <- function()
{
	Try(oneChannelGUIHelpIndex <- file.path(system.file("doc",package="oneChannelGUI"),"index.html"))
	Try(browseURL(oneChannelGUIHelpIndex))
	##Try(tkmessageBox(title="limma Help",message=paste("Opening limma help...\nIf nothing happens, please open :\n",limmaHelpIndex,"\nyourself.",sep="")))
	Try(cat(paste("Opening oneChannelGUI help...\nIf nothing happens, please open :\n",oneChannelGUIHelpIndex,"\nyourself.",sep="")))
}
################################################################################

"AboutaffylmGUI" <- function()
{
    Try(tkmessageBox(title="About affylmGUI",message=paste("Basic affylmGUI ", getPackageVersion("affylmGUI") , ", Wettenhall et al. Bioinformatics 2004, 22:897-899, ",
                              ", using limma Version ",getPackageVersion("limma"),".  The limma package was developed by Gordon Smyth and the Graphical User Interface (GUI) was developed by James Wettenhall.",sep=""),type="ok",icon="info"))
}

################################################################################

"AboutextendedaffylmGUI" <- function()
{
    Try(tkmessageBox(title=paste("About oneChannelGUI ", getPackageVersion("oneChannelGUI"), sep=""),message=paste("Basic affylmGUI ", getPackageVersion("affylmGUI") , ", originally designed by James Wettenhall and Ken Simpson, was extended by Raffaele A. Calogero: Sanges et al. Bioinformatics 2007, 23:3406-8. ",
                              "\nUsing limma Version ",getPackageVersion("limma"),".  The limma package was developed by Gordon Smyth and the Graphical User Interface (GUI) was developed by James Wettenhall.",sep=""),type="ok",icon="info"))
}

################################################################################

"changes" <- function(){
         Try(cat("\nLatest major changes in oneChannelGUI:\n"))
         Try(cat("\n1.8.8 Bioconductor BeadStudion V3:"))
         Try(cat("\n\treport generated by BeadStudio V3 can be loaded in oneChannelGUI\n."))
         Try(cat("\n\tBeadStudio V3 report MUST be a GROUP PROBE PROFILE containing the following fields:\n"))
         Try(cat("\n\t\tColumns:\n"))
         Try(cat("\n\t\tProbeId\n"))
         Try(cat("\n\t\tXXXXXXX_A\n"))
         Try(cat("\n\t\t.........\n"))
         Try(cat("\n\t\tXXXXXXX_F\n"))
         Try(cat("\n\t\t\tSubcolumns:\n"))
         Try(cat("\n\t\t\tAVG_Signal\n."))
         Try(cat("\n1.8.9 Bioconductor:"))
         Try(cat("\n\tfast parameter in GCRMA is set to FALSE\n."))
         Try(cat("\n1.10.7 Bioconductor:"))
         Try(cat("\n\tRevised annotation for variant exons has been added. After statistical detection of putative splicing\n."))
         Try(cat("\n\tit is now possible to select only exon-level probesets associated to non-costitutive exons,\n."))
         Try(cat("\n\ti.e. those exons associated only to a to a subset of isoforms\n."))
         Try(cat("\n1.10.8 Bioconductor:"))
         Try(cat("\n\tAdded Cosie method to correct SI index: Gaidatzis et al. Nucleic Acids Research, 2009, pg. 1\n."))
         Try(cat("\n\tSince intcor function from metaArray package has a bug it was sobstituted by intCor from MergeMaid package\n."))
         #gathering affy libs and apt tools folders
         Try(netaffxUpdates  <- paste(path.package("oneChannelGUI", quiet = FALSE), "/etc/netaffxUpdates.txt", sep=""))
         Try(cat("\nNetaffx library files were updated from user on:\n"))
         Try(cat(readLines(netaffxUpdates), sep="\n"))
}
